==> igniteui-react-charts-16.6.4.tgz: package/ES2015/ScatterPolylineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ShapeSeriesBase } from "./ShapeSeriesBase";
import { StyleSelector } from "./StyleSelector";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Style } from "igniteui-react-core/ES2015/Style";
import { Type, markType, typeCast } from "igniteui-react-core/ES2015/type";
import { ShapeSeriesViewBase } from "./ShapeSeriesViewBase";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { Path } from "igniteui-react-core/ES2015/Path";
import { stringIsNullOrEmpty } from "igniteui-react-core/ES2015/string";
export class ScatterPolylineSeries extends ShapeSeriesBase {
    constructor() {
        super();
        this.ab = ScatterPolylineSeries.$;
    }
    bf() {
        return new ScatterPolylineSeriesView(this);
    }
    il(a) {
        super.il(a);
        this.mz = a;
    }
    get_l6() {
        return false;
    }
    ir(a, b, c, d) {
        super.ir(a, b, c, d);
        switch (b) {
            case ScatterPolylineSeries.$$p[0]:
                this.mz.cn(this.m5);
                this.i4(false);
                this.ib();
                break;
            case ScatterPolylineSeries.$$p[1]:
                this.mz.co(this.m0);
                this.i4(false);
                this.ib();
                break;
        }
    }
    mp(a) {
        let b = a;
        b.cn(this.m5);
        b.co(this.m0);
        super.mp(a);
    }
    ar(a, b) {
        let c = this.mz.cs(a, b, true);
        if (c != null) {
            return c.dataContext;
        }
        return super.ar(a, b);
    }
}
ScatterPolylineSeries.$t = markType(ScatterPolylineSeries, 'ScatterPolylineSeries', ShapeSeriesBase.$);
Type.dep(DependencyProperty, PropertyMetadata, ScatterPolylineSeries, 'raisePropertyChanged', ['ShapeStyle:m5:m3', [Style.$, null], 'ShapeStyleSelector:m0:m4', [StyleSelector.$, null]]);
export class ScatterPolylineSeriesView extends ShapeSeriesViewBase {
    constructor(a) {
        super(a);
    }
    cu(a, b) {
        return this.cv(a, b, false);
    }
    cc(a, b) {
        super.cc(a, b);
        ShapeSeriesViewBase.cb(this, a, b);
    }
    ca(a, b) {
        let c = typeCast(Path.$, a);
        if (c == null) {
            return;
        }
        c.aj = b;
    }
    bb(a, b) {
        super.bb(a, b);
        let c = a;
        c._fill = null;
    }
    bc(a, b) {
        super.bc(a, b);
        let c = a;
        c._fill = null;
    }
    b2(a) {
        return a.width >= this.by.mf || a.height >= this.by.mf;
    }
    getDefaultTooltipTemplate() {
        let a = "<div class='ui-chart-default-tooltip-content'><span";
        let b = this.e.a0.a$q(this.e);
        if (!stringIsNullOrEmpty(b)) {
            a += " style='color:" + b + "'";
        }
        a += ">" + this.by.fr + "</span><br/>";
        a += "</div>";
        return a;
    }
}
ScatterPolylineSeriesView.$t = markType(ScatterPolylineSeriesView, 'ScatterPolylineSeriesView', ShapeSeriesViewBase.$);

==> igniteui-react-charts-16.6.7.tgz: package/ES2015/ScatterPolylineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ShapeSeriesBase } from "./ShapeSeriesBase";
import { StyleSelector } from "./StyleSelector";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Style } from "igniteui-react-core/ES2015/Style";
import { Type, markType, typeCast } from "igniteui-react-core/ES2015/type";
import { ShapeSeriesViewBase } from "./ShapeSeriesViewBase";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { Path } from "igniteui-react-core/ES2015/Path";
import { stringIsNullOrEmpty } from "igniteui-react-core/ES2015/string";
/**
 * @hidden
 */
export class ScatterPolylineSeries extends ShapeSeriesBase {
    constructor() {
        super();
        this.ab = ScatterPolylineSeries.$;
    }
    bf() {
        return new ScatterPolylineSeriesView(this);
    }
    im(a) {
        super.im(a);
        this.m1 = a;
    }
    get_l8() {
        return false;
    }
    is(a, b, c, d) {
        super.is(a, b, c, d);
        switch (b) {
            case ScatterPolylineSeries.$$p[0]:
                this.m1.cn(this.m7);
                this.i6(false);
                this.ic();
                break;
            case ScatterPolylineSeries.$$p[1]:
                this.m1.co(this.m2);
                this.i6(false);
                this.ic();
                break;
        }
    }
    mr(a) {
        let b = a;
        b.cn(this.m7);
        b.co(this.m2);
        super.mr(a);
    }
    ar(a, b) {
        let c = this.m1.cs(a, b, true);
        if (c != null) {
            return c.dataContext;
        }
        return super.ar(a, b);
    }
}
ScatterPolylineSeries.$t = markType(ScatterPolylineSeries, 'ScatterPolylineSeries', ShapeSeriesBase.$);
Type.dep(DependencyProperty, PropertyMetadata, ScatterPolylineSeries, 'raisePropertyChanged', ['ShapeStyle:m7:m5', [Style.$, null], 'ShapeStyleSelector:m2:m6', [StyleSelector.$, null]]);
/**
 * @hidden
 */
export class ScatterPolylineSeriesView extends ShapeSeriesViewBase {
    constructor(a) {
        super(a);
    }
    cu(a, b) {
        return this.cv(a, b, false);
    }
    cc(a, b) {
        super.cc(a, b);
        ShapeSeriesViewBase.cb(this, a, b);
    }
    ca(a, b) {
        let c = typeCast(Path.$, a);
        if (c == null) {
            return;
        }
        c.aj = b;
    }
    bb(a, b) {
        super.bb(a, b);
        let c = a;
        c._fill = null;
    }
    bc(a, b) {
        super.bc(a, b);
        let c = a;
        c._fill = null;
    }
    b2(a) {
        return a.width >= this.by.mh || a.height >= this.by.mh;
    }
    getDefaultTooltipTemplate() {
        let a = "<div class='ui-chart-default-tooltip-content'><span";
        let b = this.e.a0.a$q(this.e);
        if (!stringIsNullOrEmpty(b)) {
            a += " style='color:" + b + "'";
        }
        a += ">" + this.by.fs + "</span><br/>";
        a += "</div>";
        return a;
    }
}
ScatterPolylineSeriesView.$t = markType(ScatterPolylineSeriesView, 'ScatterPolylineSeriesView', ShapeSeriesViewBase.$);
